﻿/*FileName:         SETPaint.cs
/*Programmer:       Brian Hinds
/*Version:          1.0.0
/*Date:             10-07-2015
/*Description:      Painting application that draws shapes.
*/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SETPaint
{
    /*--------------*/
    /*SETPaint Class*/
    /*--------------*/

    public partial class SETPaint : Form
    {
        /*Variables*/
        private int mouseStartX = 0;
        private int mouseStartY = 0;
        private int mouseCurrentX = 0;
        private int mouseCurrentY = 0;
        private int recSartPointX = 0;
        private int recSartPointY = 0;
        private int recSizeY = 0;
        private int recSizeX = 0;
        private bool mouseDown = false;
        private Bitmap bm;
        private int shapeSelected = 0;
        private Color setPaintColor;
        private Color setPaintColorFill;

        /*Initialize the components for SETPaint*/

        public SETPaint()
        {
            InitializeComponent();
            bm = new Bitmap(canvas.Width, canvas.Height);
            setPaintColor = Color.Black;
            setPaintColorFill = Color.Violet;
        }

        /*This is the canvas paint area for the shapes*/

        private void canvas_Paint(object sender, PaintEventArgs e)
        {
            Graphics setPaint = e.Graphics;
            if (mouseDown == true)
            {
                /*Sets the thickness of the line or boarder of the shapes.*/
                Pen size = new Pen(setPaintColor, float.Parse(lineSize.Text));
                if (shapeSelected == 1)
                {
                    /*Draws line*/
                    setPaint.DrawLine(size, new Point(mouseStartX, mouseStartY), new Point(mouseCurrentX + mouseStartX, mouseCurrentY + mouseStartY));
                }
                else if (shapeSelected == 2)
                {
                    //Draws ellipse boarder.
                    setPaint.DrawEllipse(size, mouseStartX, mouseStartY, mouseCurrentX, mouseCurrentY);
                }
                else if (shapeSelected == 3)
                {
                    //Draws rectangle boarder.
                    setPaint.DrawRectangle(size, recSartPointX, recSartPointY, recSizeX, recSizeY);
                }
            }
            //Paints to bitmap
            setPaint.DrawImage(bm, new Point(0, 0));
        }

        //This section determine what happens when the mouse is up.
        private void canvas_MouseUp(object sender, MouseEventArgs e)
        {
            if (e.Button == MouseButtons.Left)
            {
                //This is the size of the line or the boarder of the shape.
                Pen size = new Pen(setPaintColor, float.Parse(lineSize.Text));

                mouseDown = false;
                Graphics setPaint = Graphics.FromImage(bm);

                if (shapeSelected == 1)
                {
                    //Draws the line
                    setPaint.DrawLine(size, new Point(mouseStartX, mouseStartY), new Point(mouseCurrentX + mouseStartX, mouseCurrentY + mouseStartY));
                }
                else if (shapeSelected == 2)
                {
                    //draws the ellipse with the boarder.
                    setPaint.DrawEllipse(size, mouseStartX, mouseStartY, mouseCurrentX, mouseCurrentY);
                    setPaint.FillEllipse(new SolidBrush(setPaintColorFill), mouseStartX, mouseStartY, mouseCurrentX, mouseCurrentY);
                }
                else if (shapeSelected == 3)
                {
                    //Draws the rectangle with the boarder.
                    setPaint.DrawRectangle(size, recSartPointX, recSartPointY, recSizeX, recSizeY);
                    setPaint.FillRectangle(new SolidBrush(setPaintColorFill), recSartPointX, recSartPointY, recSizeX, recSizeY);
                }
            }
        }

        //This section determine what happens when the mouse is down on the canvas.
        private void canvas_MouseDown(object sender, MouseEventArgs e)
        {
            if (e.Button == MouseButtons.Left)
            {
                mouseDown = true;
                mouseStartX = e.X;
                mouseStartY = e.Y;
            }
        }

        //This section determines what happens when the mouse is moving on the canvas.
        private void canvas_MouseMove(object sender, MouseEventArgs e)
        {
            //Displays the mouse position.
            textBox1.Text = Convert.ToString(mouseCurrentX);
            textBox2.Text = Convert.ToString(mouseCurrentY);

            if (mouseDown == true)
            {
                mouseCurrentX = e.X - mouseStartX;
                mouseCurrentY = e.Y - mouseStartY;

                canvas.Invalidate();
            }
            else
            {
                canvas.Invalidate();
            }
            //Calculate and determine where the rectangle should be drawn.
            //The x-value of our rectangle should be the minimum between the start x-value and the current x-position
            recSartPointX = Math.Min(mouseStartX, e.X);
            //The y-value of our rectangle should also be the minimum between the start y-value and current y-value
            recSartPointY = Math.Min(mouseStartY, e.Y);
            //The width (recSizeX) of our rectangle should be the maximum between the start x-position and current x-position minus
            //the minimum of start x-position and current x-position
            recSizeX = Math.Max(mouseStartX, e.X) - Math.Min(mouseStartX, e.X);
            //For the hight(recSizeY) value, it's basically the same thing as above, but now with the y-values:
            recSizeY = Math.Max(mouseStartY, e.Y) - Math.Min(mouseStartY, e.Y);
        }

        //These syntax handles the tool strip section of the application.
        private void toolStripComboBox1_Click(object sender, EventArgs e)
        {
        }
        //This button allows tyhe user to draw a line.
        private void toolStripButton1_Click(object sender, EventArgs e)
        {
            shapeSelected = 1;
        }
        //This button allows tyhe user to draw an ellipse.
        private void toolStripButton2_Click(object sender, EventArgs e)
        {
            shapeSelected = 2;
        }
        //This button allows tyhe user to draw a rectangle.
        private void toolStripButton3_Click(object sender, EventArgs e)
        {
            shapeSelected = 3;
        }
        //This button changes the line or boarder color to the given syntax color.
        private void toolStripButton4_Click(object sender, EventArgs e)
        {
            setPaintColor = Color.Black;
        }
        //This button changes the line or boarder color to the given syntax color.
        private void toolStripButton5_Click(object sender, EventArgs e)
        {
            setPaintColor = Color.Blue;
        }
        //This button changes the line or boarder color to the given syntax color.
        private void toolStripButton6_Click(object sender, EventArgs e)
        {
            setPaintColor = Color.Green;
        }
        //This button changes the line or boarder color to the given syntax color.
        private void toolStripButton7_Click(object sender, EventArgs e)
        {
            setPaintColor = Color.Purple;
        }
        //This button changes the line or boarder color to the given syntax color.
        private void toolStripButton8_Click(object sender, EventArgs e)
        {
            setPaintColor = Color.Red;
        }
        //This button changes the line or boarder color to the given syntax color.
        private void toolStripButton9_Click(object sender, EventArgs e)
        {
            setPaintColor = Color.Yellow;
        }

        //This section calls the color dialog for the boarder.
        private void toolStripButton13_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Do you want to clear drawing and start new?", "Clear", MessageBoxButtons.YesNo, MessageBoxIcon.Information) == DialogResult.Yes)
            {
                bm = new Bitmap(canvas.Width, canvas.Height);
                canvas.BackgroundImage = bm;
                Graphics setPaint = Graphics.FromImage(bm);
                setPaint.Clear(canvas.BackColor);
                setPaint.Dispose();
            }
        }

        //This section calls the color dialog for the boarder.
        private void toolStripButton10_Click(object sender, EventArgs e)
        {
            ColorDialog colorWheel = new ColorDialog();
            if (colorWheel.ShowDialog() == DialogResult.OK)
            {
                setPaintColor = colorWheel.Color;
            }
        }

        //This section saves the image by calling the SaveFileDialog.
        private void toolStripButton12_Click(object sender, EventArgs e)
        {
            Bitmap bm = new Bitmap(canvas.Width, canvas.Height);
            Graphics setPaint = Graphics.FromImage(bm);
            Rectangle rect = canvas.RectangleToScreen(canvas.ClientRectangle);
            setPaint.CopyFromScreen(rect.Location, Point.Empty, canvas.Size);
            canvas.Dispose();

            SaveFileDialog save = new SaveFileDialog();
            save.Filter = "Png files| *.png| jpeg files| *jpg| bitmaps| *bmp";

            if (save.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                try
                {
                    if (File.Exists(save.FileName))
                    {
                        File.Delete(save.FileName);
                    }
                    if (save.FileName.Contains(".jpg"))
                    {
                        bm.Save(save.FileName, ImageFormat.Jpeg);
                    }
                    else if (save.FileName.Contains(".png"))
                    {
                        bm.Save(save.FileName, ImageFormat.Png);
                    }
                    else if (save.FileName.Contains(".bmp"))
                    {
                        bm.Save(save.FileName, ImageFormat.Bmp);
                    }
                }
                catch (Exception ex)
                {
                    MessageBox.Show("File save error : " + ex.Message);
                }
            }
        }

        //This section opens image files by calling the OpenFileDialog.
        private void openPaint_Click(object sender, EventArgs e)
        {
            OpenFileDialog open = new OpenFileDialog();
            open.Filter = "Png files| *.png| jpeg files| *jpg| bitmaps| *bmp";
            if (open.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                try
                {
                    Bitmap oldbm = bm;
                    bm = new Bitmap(open.FileName);
                    oldbm.Dispose();
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Error loading image " + ex.Message);
                }
                
            }
        }

        //This section saves the image by calling the SaveFileDialog.
        private void saveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Bitmap bm = new Bitmap(canvas.Width, canvas.Height);
            Graphics setPaint = Graphics.FromImage(bm);
            Rectangle rect = canvas.RectangleToScreen(canvas.ClientRectangle);
            setPaint.CopyFromScreen(rect.Location, Point.Empty, canvas.Size);
            canvas.Dispose();
            SaveFileDialog save = new SaveFileDialog();
            save.Filter = "Png files| *.png| jpeg files| *jpg| bitmaps| *bmp";

            if (save.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                try
                {
                    if (File.Exists(save.FileName))
                    {
                        File.Delete(save.FileName);
                    }
                    if (save.FileName.Contains(".jpg"))
                    {
                        bm.Save(save.FileName, ImageFormat.Jpeg);
                    }
                    else if (save.FileName.Contains(".png"))
                    {
                        bm.Save(save.FileName, ImageFormat.Png);
                    }
                    else if (save.FileName.Contains(".bmp"))
                    {
                        bm.Save(save.FileName, ImageFormat.Bmp);
                    }
                }
                catch (Exception ex)
                {
                    MessageBox.Show("File save error : " + ex.Message);
                }
            }
        }

    
        //This section opens image files by calling the OpenFileDialog.
        private void openToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenFileDialog open = new OpenFileDialog();
            open.Filter = "Png files| *.png| jpeg files| *jpg| bitmaps| *bmp";

            if (open.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                try
                {
                    Bitmap oldbm = bm;
                    bm = new Bitmap(open.FileName);
                    oldbm.Dispose();
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Error loading image " + ex.Message);
                }

            }
        }

        //This section calls the color dialog for the filling of shapes.
        private void toolStripButton18_Click(object sender, EventArgs e)
        {
            ColorDialog fillColorWheel = new ColorDialog();
            if (fillColorWheel.ShowDialog() == DialogResult.OK)
            {
                setPaintColorFill = fillColorWheel.Color;
            }
        }

        //This section handles the filling of the shapes to the define syntax color.
        private void toolStripButton11_Click(object sender, EventArgs e)
        {
            setPaintColorFill = Color.Black;
        }
        //This section handles the filling of the shapes to the define syntax color.
        private void toolStripButton14_Click(object sender, EventArgs e)
        {
            setPaintColorFill = Color.Blue;
        }
        //This section handles the filling of the shapes to the define syntax color.
        private void toolStripButton15_Click(object sender, EventArgs e)
        {
            setPaintColorFill = Color.Green;
        }
        //This section handles the filling of the shapes to the define syntax color.
        private void toolStripButton16_Click(object sender, EventArgs e)
        {
            setPaintColorFill = Color.Purple;
        }
        //This section handles the filling of the shapes to the define syntax color.
        private void toolStripButton17_Click(object sender, EventArgs e)
        {
            setPaintColorFill = Color.Red;
        }
        //This section handles the filling of the shapes to the define syntax color.
        private void toolStripButton19_Click(object sender, EventArgs e)
        {
            setPaintColorFill = Color.Yellow;
        }

        //This section handles the exit command in from the file menu.
        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Do you want to Exit?", "Exit", MessageBoxButtons.YesNo, MessageBoxIcon.Information) == DialogResult.Yes)
            {
                Application.Exit();
            }
        }

        //This section handles the about dialog box.
        private void aboutSETPaintToolStripMenuItem_Click(object sender, EventArgs e)
        {
             About about = new About();
            about.ShowDialog();
        }

        //This section calls the color dialog for the boarder.
        private void newToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Do you want to clear drawing and start new?", "Clear", MessageBoxButtons.YesNo, MessageBoxIcon.Information) == DialogResult.Yes)
            {
                bm = new Bitmap(canvas.Width, canvas.Height);
                canvas.BackgroundImage = bm;
                Graphics setPaint = Graphics.FromImage(bm);
                setPaint.Clear(canvas.BackColor);
                setPaint.Dispose();
            }
        }
    }
}